import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="sauces",
    version="0.0.1",
    author="Bits Team",
    description="The easiest way to distribute and download datasets! Used by authors and competition organizers in NeurIPS, CVPR, ACL.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/greentfrapp/sauces",
    project_urls={
        "Source": "https://github.com/greentfrapp/sauces",
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    packages=setuptools.find_packages(),
    python_requires=">=3.6",
)
